==> rlstyles-2.0.0.tar.gz: lib/Component/Styles.dart <==
class Styles {
  const Styles(
      {this.display = 'display',
      this.flexDirection = 'row',
      this.backgroundColor,
      this.backgroundImage,
      this.width,
      this.height,
      this.color,
      this.justifyContent,
      this.alignItems,
      this.borderRadius,
      this.marginLeft,
      this.marginTop,
      this.marginRight,
      this.marginBottom,
      this.paddingLeft,
      this.paddingTop,
      this.paddingRight,
      this.paddingBottom,
      this.left,
      this.top,
      this.right,
      this.bottom,
      this.position = 'rel',
      this.maxHeight,
      this.maxWidth,
      this.fontSize,
      this.textOverflow,
      this.fontWeight,
      this.fontFamily,
      this.whiteSpace,
      this.lineHeight,
      this.textDecoration,
      this.overflow,
      this.lines,
      this.boxSizing,
      this.borderColor,
      this.borderStyle = 'solid',
      this.borderWidth = 1,
      this.opacity = 1.0,
      this.boxShadow,
      this.textAlign,
      this.minHeight,
      this.minWidth,
      this.letterSpacing,
      this.borderBottomLeftRadius,
      this.borderBottomRightRadius,
      this.borderBottomColor,
      this.borderBottomStyle = 'solid',
      this.borderBottomWidth,
      this.borderLeftColor,
      this.borderLeftStyle = 'solid',
      this.borderLeftWidth,
      this.borderRightColor,
      this.borderRightStyle = 'solid',
      this.borderRightWidth,
      this.borderTopColor,
      this.borderTopStyle = 'solid',
      this.borderTopWidth,
      this.borderTopRightRadius,
      this.borderTopLeftRadius,
      this.flex = 0,
      this.overflowX,
      this.overflowY,
      this.transform,
      this.flexWrap,
      this.flexWrapSpacing,
      this.flexWrapRunSpacing,
      this.backgroundSize,
      this.margin,
      this.padding,
      this.elevation,
      this.zIndex = 1,
      this.gridCount,
      this.gridChildAspectRatio,
      this.gridCrossAxisSpacing,
      this.gridMainAxisSpacing});
  final String display;
  final dynamic color;
  final dynamic width;
  final dynamic height;
  final String flexDirection;
  final String? flexWrap;
  final dynamic flexWrapSpacing;
  final dynamic flexWrapRunSpacing;
  final String? justifyContent;
  final String? alignItems;
  final dynamic borderRadius;
  final dynamic marginLeft;
  final dynamic marginTop;
  final dynamic marginRight;
  final dynamic marginBottom;
  final dynamic paddingLeft;
  final dynamic paddingTop;
  final dynamic paddingRight;
  final dynamic paddingBottom;
  final dynamic left;
  final dynamic top;
  final dynamic right;
  final dynamic bottom;
  final String position;
  final String? backgroundImage;
  final dynamic backgroundColor;
  final dynamic maxWidth;
  final dynamic maxHeight;
  final dynamic fontSize;
  final String? textOverflow;
  final dynamic fontWeight;
  final String? fontFamily;
  final String? whiteSpace;
  final dynamic lineHeight;
  final String? textDecoration;
  final String? overflow;
  final int? lines;
  final String? boxSizing;
  final dynamic borderWidth;
  final String borderStyle;
  final dynamic borderColor;
  final double opacity;
  final dynamic boxShadow;
  final String? textAlign;
  final dynamic minHeight;
  final dynamic minWidth;
  final double? borderBottomLeftRadius;
  final double? borderBottomRightRadius;
  final String borderLeftStyle;
  final dynamic borderLeftColor;
  final dynamic borderLeftWidth;
  final String borderRightStyle;
  final dynamic borderRightColor;
  final dynamic borderRightWidth;
  final String borderTopStyle;
  final dynamic borderTopColor;
  final dynamic borderTopWidth;
  final String borderBottomStyle;
  final dynamic borderBottomColor;
  final dynamic borderBottomWidth;
  final dynamic borderTopLeftRadius;
  final dynamic borderTopRightRadius;
  final int? flex;
  final String? overflowY;
  final String? overflowX;
  final double? letterSpacing;
  final String? transform;
  final dynamic backgroundSize;
  final dynamic margin;
  final dynamic padding;
  final dynamic elevation;
  final int zIndex;
  final int? gridCount;
  final double? gridMainAxisSpacing;
  final double? gridCrossAxisSpacing;
  final double? gridChildAspectRatio;
}

==> rlstyles-2.0.3.tar.gz: lib/Component/Styles.dart <==
class Styles {
  const Styles(
      {this.display = 'display',
      this.flexDirection = 'col',
      this.backgroundColor,
      this.backgroundImage,
      this.width,
      this.height,
      this.color,
      this.justifyContent,
      this.alignItems,
      this.borderRadius,
      this.marginLeft,
      this.marginTop,
      this.marginRight,
      this.marginBottom,
      this.paddingLeft,
      this.paddingTop,
      this.paddingRight,
      this.paddingBottom,
      this.left,
      this.top,
      this.right,
      this.bottom,
      this.position = 'rel',
      this.maxHeight,
      this.maxWidth,
      this.fontSize,
      this.textOverflow,
      this.fontWeight,
      this.fontFamily,
      this.whiteSpace,
      this.lineHeight,
      this.textDecoration,
      this.lines,
      this.boxSizing,
      this.borderColor,
      this.borderStyle = 'solid',
      this.borderWidth = 1,
      this.opacity = 1.0,
      this.boxShadow,
      this.textAlign,
      this.minHeight,
      this.minWidth,
      this.letterSpacing,
      this.borderBottomLeftRadius,
      this.borderBottomRightRadius,
      this.borderBottomColor,
      this.borderBottomStyle = 'solid',
      this.borderBottomWidth,
      this.borderLeftColor,
      this.borderLeftStyle = 'solid',
      this.borderLeftWidth,
      this.borderRightColor,
      this.borderRightStyle = 'solid',
      this.borderRightWidth,
      this.borderTopColor,
      this.borderTopStyle = 'solid',
      this.borderTopWidth,
      this.borderTopRightRadius,
      this.borderTopLeftRadius,
      this.flex,
      this.overflowX,
      this.overflowY,
      this.transform,
      this.flexWrap,
      this.flexWrapSpacing,
      this.flexWrapRunSpacing,
      this.backgroundSize,
      this.margin,
      this.padding,
      this.elevation,
      this.zIndex = 1,
      this.gridCount,
      this.gridChildAspectRatio,
      this.gridCrossAxisSpacing,
      this.gridMainAxisSpacing,
      this.scrollBar = true});
  final bool scrollBar;
  final String display;
  final dynamic color;
  final dynamic width;
  final dynamic height;
  final String flexDirection;
  final String? flexWrap;
  final dynamic flexWrapSpacing;
  final dynamic flexWrapRunSpacing;
  final String? justifyContent;
  final String? alignItems;
  final dynamic borderRadius;
  final dynamic marginLeft;
  final dynamic marginTop;
  final dynamic marginRight;
  final dynamic marginBottom;
  final dynamic paddingLeft;
  final dynamic paddingTop;
  final dynamic paddingRight;
  final dynamic paddingBottom;
  final dynamic left;
  final dynamic top;
  final dynamic right;
  final dynamic bottom;
  final String position;
  final String? backgroundImage;
  final dynamic backgroundColor;
  final dynamic maxWidth;
  final dynamic maxHeight;
  final dynamic fontSize;
  final String? textOverflow;
  final dynamic fontWeight;
  final String? fontFamily;
  final String? whiteSpace;
  final dynamic lineHeight;
  final String? textDecoration;
  final int? lines;
  final String? boxSizing;
  final dynamic borderWidth;
  final String borderStyle;
  final dynamic borderColor;
  final double opacity;
  final dynamic boxShadow;
  final String? textAlign;
  final dynamic minHeight;
  final dynamic minWidth;
  final double? borderBottomLeftRadius;
  final double? borderBottomRightRadius;
  final String borderLeftStyle;
  final dynamic borderLeftColor;
  final dynamic borderLeftWidth;
  final String borderRightStyle;
  final dynamic borderRightColor;
  final dynamic borderRightWidth;
  final String borderTopStyle;
  final dynamic borderTopColor;
  final dynamic borderTopWidth;
  final String borderBottomStyle;
  final dynamic borderBottomColor;
  final dynamic borderBottomWidth;
  final dynamic borderTopLeftRadius;
  final dynamic borderTopRightRadius;
  final int? flex;
  final String? overflowY;
  final String? overflowX;
  final double? letterSpacing;
  final dynamic transform;
  final dynamic backgroundSize;
  final dynamic margin;
  final dynamic padding;
  final dynamic elevation;
  final int zIndex;
  final int? gridCount;
  final double? gridMainAxisSpacing;
  final double? gridCrossAxisSpacing;
  final double? gridChildAspectRatio;
}
